powered by
This function performs a Duane analysis (1962) doi:10.1109/TA.1964.4319640 on the provided failure data.
duane_plot( times, failures, plot = TRUE, log = TRUE, point_col = "black", line_col = "black", xlab = "Cumulative Time", ylab = "Cumulative MTBF", main = "Duane Plot with Cumulative MTBF" )
A list containing the fitted model, AIC, and BIC.
A vector of cumulative times at which failures occurred.
A vector of the number of failures at each corresponding time in times.
Show Duane plot (TRUE) or hide plot (FALSE).
Logical indicating whether to use logarithmic scale for the plot (default: TRUE).
Color for the data points (default: "black").
Color for the fitted line (default: "black").
Label for the x-axis (default: "Cumulative Time").
Label for the y-axis (default: "Cumulative MTBF").
Title for the plot (default: "Duane Plot with Cumulative MTBF").
times <- c(100, 200, 300, 400, 500) failures <- c(1, 2, 1, 3, 2) fit <- duane_plot(times, failures) print(fit)
Run the code above in your browser using DataLab