| overlay_nhpp | R Documentation |
Plots multiple fitted nhpp objects on a single set of axes, using
distinct colors per model. Observed data points, fitted lines, and optional
confidence bounds are drawn for every model. Models may have been fit to
different datasets.
overlay_nhpp(
models,
conf_bounds = TRUE,
legend = TRUE,
legend_pos = "topleft",
colors = NULL,
...
)
models |
A named or unnamed list of objects of class |
conf_bounds |
Logical; draw confidence bounds for each model
(default: |
legend |
Logical; draw a legend (default: |
legend_pos |
Legend position keyword (default: |
colors |
Optional character vector of colors, one per model. If
|
... |
Additional arguments passed to the initial |
Invisibly returns NULL.
Other Repairable Systems Analysis:
exposure(),
mcf(),
nhpp(),
plot.exposure(),
plot.mcf(),
plot.nhpp(),
plot.nhpp_predict(),
predict_nhpp(),
print.exposure(),
print.mcf(),
print.nhpp(),
print.nhpp_predict()
t1 <- c(200, 400, 600, 800, 1000)
e1 <- c(3, 5, 4, 7, 6)
t2 <- c(300, 600, 900, 1200, 1500)
e2 <- c(4, 6, 5, 8, 7)
m1 <- nhpp(t1, e1)
m2 <- nhpp(t2, e2)
overlay_nhpp(list(System_A = m1, System_B = m2),
main = "NHPP Overlay", xlab = "Time",
ylab = "Cumulative Events"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.