| predict_duane | R Documentation |
Takes a fitted duane object and a vector of cumulative times, returning
predicted MTBF with confidence bounds as a duane_predict S3 object.
predict_duane(object, times, conf_level = 0.95)
object |
An object of class |
times |
A numeric vector of cumulative times at which to forecast MTBF. All values must be finite and > 0. A warning is issued if any value is at or below the maximum observed cumulative time (hindcasting). |
conf_level |
The desired confidence level (default |
An object of class duane_predict containing:
times |
The forecast cumulative times. |
mtbf |
Predicted MTBF values. |
lower_bounds |
Lower confidence bounds on MTBF. |
upper_bounds |
Upper confidence bounds on MTBF. |
conf_level |
The confidence level used. |
duane_object |
The original |
Other Duane functions:
duane(),
plot.duane(),
plot.duane_predict(),
print.duane(),
print.duane_predict()
times <- c(100, 200, 300, 400, 500)
failures <- c(1, 2, 1, 3, 2)
fit <- duane(times, failures)
fc <- predict_duane(fit, times = c(1000, 2000))
print(fc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.