| predict_rga | R Documentation |
Takes a fitted rga object and a vector of cumulative times, returning
predicted cumulative failures with confidence bounds as an rga_predict
S3 object.
predict_rga(object, times, conf_level = 0.95)
object |
An object of class |
times |
A numeric vector of cumulative times at which to forecast. All values must be finite and > 0. A warning is issued if any value is at or below the maximum observed cumulative time (hindcasting). |
conf_level |
The desired confidence level (default |
An object of class rga_predict containing:
times |
The forecast cumulative times. |
cum_failures |
Predicted cumulative failures. |
lower_bounds |
Lower confidence bounds. |
upper_bounds |
Upper confidence bounds. |
conf_level |
The confidence level used. |
model_type |
Either |
rga_object |
The original |
Other Reliability Growth Analysis:
overlay_rga(),
plot.rga(),
plot.rga_predict(),
print.rga(),
print.rga_predict(),
rga()
times <- c(100, 200, 300, 400, 500)
failures <- c(1, 2, 1, 3, 2)
fit <- rga(times, failures)
fc <- predict_rga(fit, times = c(1500, 2000))
print(fc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.