powered by
This function performs reliability growth analysis using the Crow-AMSAA model by Crow (1975) https://apps.dtic.mil/sti/citations/ADA020296 or piecewise NHPP model by Guo et al. (2010) doi:10.1109/RAMS.2010.5448029.
rga( times, failures, model_type = "Crow-AMSAA", breaks = NULL, conf_level = 0.95 )
The function returns an object of class rga that contains the results for the model.
rga
A vector of cumulative times at which failures occurred.
A vector of the number of failures at each corresponding time in times.
The model type. Either Crow-AMSAA (default) or Piecewise NHPP with change point detection.
Crow-AMSAA
Piecewise NHPP
An optional vector of breakpoints for the Piecewise NHPP model.
The desired confidence level, which defaults to 95%.
times <- c(100, 200, 300, 400, 500) failures <- c(1, 2, 1, 3, 2) result <- rga(times, failures) print(result)
Run the code above in your browser using DataLab