| rga_mcp_server | R Documentation |
Starts a Model Context Protocol (MCP) server that exposes the core ReliaGrowR analysis functions as tools for AI assistants such as Claude.
rga_mcp_server(...)
... |
Additional arguments passed to |
Requires the mcptools and ellmer packages to be installed.
Called for its side effect of starting the MCP server.
rgaFit Crow-AMSAA reliability growth model
nhppFit NHPP model for repairable systems
duaneFit Duane log-log reliability growth model
mcfCompute Mean Cumulative Function
predict_rgaForecast from RGA model
predict_duaneForecast MTBF from Duane model
rdtPlan a Reliability Demonstration Test
gof_rgaGoodness-of-fit statistics for RGA model
claude mcp add -s user reliagrowR -- Rscript -e "ReliaGrowR::rga_mcp_server()"
{
"mcpServers": {
"reliagrowR": {
"command": "Rscript",
"args": ["-e", "ReliaGrowR::rga_mcp_server()"]
}
}
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.